@@ -80,8 +80,6 @@ class BuildPage(QWidget):
 
         self._clean_button = QCheckBox("Clean before building", checked=True)
         options_layout.addWidget(self._clean_button)
-        self._console_button = QCheckBox("Capture console output")
-        options_layout.addWidget(self._console_button)
         self._verbose_button = QCheckBox("Verbose output")
         options_layout.addWidget(self._verbose_button)
 
@@ -116,19 +114,15 @@ class BuildPage(QWidget):
         # Check the prerequisites.  Note that we don't disable the button if
         # these are missing because (as they are spread across the GUI) the
         # user would have difficulty knowing what needed fixing.
-        if project.application_script == '':
-            self._missing_prereq("main script file")
-            return
-
         if project.python_host_interpreter == '':
             self._missing_prereq("host interpreter")
             return
 
-        if project.application_script == '':
+        if project.python_target_include_dir == '':
             self._missing_prereq("target Python include directory")
             return
 
-        if project.application_script == '':
+        if project.python_target_library == '':
             self._missing_prereq("target Python library")
             return
 
@@ -147,8 +141,7 @@ class BuildPage(QWidget):
             opt = 0
 
         try:
-            builder.build(opt, clean=bool(self._clean_button.checkState()),
-                    console=bool(self._console_button.checkState()))
+            builder.build(opt, clean=bool(self._clean_button.checkState()))
         except UserException as e:
             logger.user_exception(e)
             handle_user_exception(e, self.label, self)
@@ -190,19 +183,18 @@ class BuildPage(QWidget):
             logger.status_message("{0} succeeded.".format(make))
 
         if self._run_application_button.checkState() != Qt.Unchecked:
-            build_dir = project.absolute_path(project.build_dir)
-            app_name = project.application_basename()
+            build_dir = project.path_from_user(project.build_dir)
+            exe_name = project.get_executable_basename()
 
             if sys.platform == 'win32':
-                application = os.path.join(build_dir, 'Release',
-                        app_name + '.exe')
-            elif sys.platform == 'darwin':
-                application = os.path.join(build_dir, app_name + '.app',
-                        'Contents', 'MacOS', app_name)
+                application = build_dir + '/Release/' + exe_name + '.exe'
+            elif sys.platform == 'darwin' and project.application_is_bundle:
+                application = '/'.join([build_dir, exe_name + '.app',
+                        'Contents', 'MacOS', exe_name])
             else:
-                application = os.path.join(build_dir, app_name)
+                application = build_dir + '/' + exe_name
 
-            logger.status_message("Running {0}...".format(app_name))
+            logger.status_message("Running {0}...".format(exe_name))
 
             try:
                 builder.run([application], "{0} failed.".format(application))
@@ -211,7 +203,7 @@ class BuildPage(QWidget):
                 handle_user_exception(e, self.label, self)
                 return
 
-            logger.status_message("{0} succeeded.".format(app_name))
+            logger.status_message("{0} succeeded.".format(exe_name))
 
     def _missing_prereq(self, missing):
         """ Tell the user about a missing prerequisite. """
