@@ -24,7 +24,7 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 
-from PyQt5.QtCore import QDir
+from PyQt5.QtCore import pyqtSignal, QDir
 from PyQt5.QtWidgets import (QFileDialog, QHBoxLayout, QLineEdit, QStyle,
         QToolButton, QWidget)
 
@@ -34,6 +34,9 @@ class FilenameEditor(QWidget):
     are relative to the project if possbile.
     """
 
+    # Emitted when the value should be auto-commited.
+    autoCommit = pyqtSignal()
+
     def __init__(self, caption, directory=False, parent=None, **kwds):
         """ Initialise the editor. """
 
@@ -87,8 +90,10 @@ class FilenameEditor(QWidget):
                     self._caption, default)
 
         if name != '':
-            name = self._project.path_to_user(name)
+            if self._project is not None:
+                name = self._project.path_to_user(name)
 
             if name != orig:
                 self._line_edit.setText(name)
                 self._line_edit.textEdited.emit(name)
+                self.autoCommit.emit()
