@@ -26,7 +26,7 @@
 
 import os
 
-from PyQt5.QtCore import QPoint, QSettings, QSize
+from PyQt5.QtCore import QFileInfo, QPoint, QSettings, QSize
 from PyQt5.QtGui import QKeySequence
 from PyQt5.QtWidgets import (QFileDialog, QMainWindow, QMessageBox, QTabWidget,
         QWhatsThis)
@@ -38,11 +38,11 @@ from ..version import PYQTDEPLOY_RELEASE
 from .application_page import ApplicationPage
 from .build_page import BuildPage
 from .exception_handlers import handle_user_exception
-from .extension_modules_page import ExtensionModulesPage
 from .locations_page import LocationsPage
-from .packages_page import PackagesPage
+from .other_extension_modules_page import OtherExtensionModulesPage
+from .other_packages_page import OtherPackagesPage
 from .pyqt_page import PyQtPage
-from .stdlib_page import StdlibPage
+from .standard_library_page import StandardLibraryPage
 
 
 class ProjectGUI(QMainWindow):
@@ -68,7 +68,7 @@ class ProjectGUI(QMainWindow):
         error.
         """
 
-        return cls._load_project(filename) if os.path.isfile(filename) else Project(filename)
+        return cls._load_project(filename) if QFileInfo(filename).exists() else Project(filename)
 
     def closeEvent(self, event):
         """ Handle a close event. """
@@ -135,14 +135,15 @@ class ProjectGUI(QMainWindow):
         pyqt_page = PyQtPage()
         tabs.addTab(pyqt_page, pyqt_page.label)
 
-        stdlib_page = StdlibPage()
-        tabs.addTab(stdlib_page, stdlib_page.label)
+        standard_library_page = StandardLibraryPage()
+        tabs.addTab(standard_library_page, standard_library_page.label)
 
-        packages_page = PackagesPage()
-        tabs.addTab(packages_page, packages_page.label)
+        other_packages_page = OtherPackagesPage()
+        tabs.addTab(other_packages_page, other_packages_page.label)
 
-        extension_modules_page = ExtensionModulesPage()
-        tabs.addTab(extension_modules_page, extension_modules_page.label)
+        other_extension_modules_page = OtherExtensionModulesPage()
+        tabs.addTab(other_extension_modules_page,
+                other_extension_modules_page.label)
 
         locations_page = LocationsPage()
         tabs.addTab(locations_page, locations_page.label)
